from typing import Any

from dev.coatl.helper.types import AnyStr
from java.lang import Object

class Aggregate:
    def getDesc(self) -> AnyStr: ...
    def getId(self) -> int: ...
    def getName(self) -> AnyStr: ...

class AggregateInfo(Object, Aggregate):
    def __init__(self, *args: Any) -> None: ...
    def getDesc(self) -> AnyStr: ...
    def getId(self) -> int: ...
    def getName(self) -> AnyStr: ...



from typing import List, Union

from com.inductiveautomation.ignition.common.project.resource import (
    ProjectResource,
    ProjectResourceId,
    ResourceType,
)
from dev.coatl.helper.types import AnyStr
from java.lang import Object

class ResourceFilter(Object):
    def __init__(
        self, applicationScope: int, resourceTypes: List[ResourceType]
    ) -> None: ...
    def apply(self, arg: Union[ProjectResource, ProjectResourceId]) -> bool: ...
    @staticmethod
    def forScope(applicationScope: int) -> ResourceFilter: ...
    def getApplicationScope(self) -> int: ...
    def getResourceTypes(self) -> List[ResourceType]: ...
    @staticmethod
    def newBuilder() -> ResourceFilter.Builder: ...

    class Builder(Object):
        def addResourceType(
            self, resourceType: ResourceType
        ) -> ResourceFilter.Builder: ...
        def addResourceTypes(
            self, resourceTypes: List[ResourceType]
        ) -> ResourceFilter.Builder: ...
        def build(self) -> ResourceFilter: ...
        def setApplicationScope(
            self, applicationScope: Union[AnyStr, int]
        ) -> ResourceFilter.Builder: ...



from typing import Any, Union

from dev.coatl.helper.types import AnyStr
from java.lang import Object
from java.math import BigDecimal
from java.nio import ByteBuffer
from java.util import Date
from org.bson import BSONObject, Document

class Binary(Object):
    def __init__(self, *args: Any) -> None: ...
    def getData(self) -> Any: ...
    def getType(self) -> Any: ...
    def length(self) -> int: ...

class BSONTimestamp(Object):
    def __init__(self, time: int = ..., increment: int = ...) -> None: ...
    def compareTo(self, ts: BSONTimestamp) -> int: ...
    def getInc(self) -> int: ...
    def getTime(self) -> int: ...

class Code(Object):
    def __init__(self, code: AnyStr) -> None: ...
    def getCode(self) -> AnyStr: ...

class CodeWScope(Code):
    def __init__(self, code: AnyStr, scope: BSONObject) -> None: ...
    def getScope(self) -> BSONObject: ...

class CodeWithScope(Code):
    def __init__(self, code: AnyStr, scope: Document) -> None: ...
    def getScope(self) -> Document: ...

class Decimal128(Object):
    Nan: Decimal128
    NEGATIVE_INFINITY: Decimal128
    NEGATIVE_NaN: Decimal128
    NEGATIVE_ZERO: Decimal128
    POSITIVE_INFINITY: Decimal128
    POSITIVE_ZERO: Decimal128
    def __init__(self, value: Union[BigDecimal, long]) -> None: ...
    def bigDecimalValue(self) -> BigDecimal: ...
    @staticmethod
    def fromIEEE754BIDEncoding(high: long, low: long) -> Decimal128: ...
    def getHigh(self) -> long: ...
    def getLow(self) -> long: ...
    def isFinite(self) -> bool: ...
    def isInfinite(self) -> bool: ...
    def isNaN(self) -> bool: ...
    def isNegative(self) -> bool: ...
    @staticmethod
    def parse(value: AnyStr) -> Decimal128: ...

class MaxKey(Object):
    def __init__(self) -> None: ...

class MinKey(Object):
    def __init__(self) -> None: ...

class ObjectId(Object):
    def __init__(self, *args: Any) -> None: ...
    @staticmethod
    def createFromLegacyFormat(time: int, machine: int, inc: int) -> ObjectId: ...
    def getCounter(self) -> int: ...
    def getDate(self) -> Date: ...
    @staticmethod
    def getGeneratedMachineIdentifier() -> int: ...
    @staticmethod
    def getGeneratedProcessIdentifier() -> int: ...
    def getMachineIdentifier(self) -> int: ...
    def getProcessIdentifier(self) -> int: ...
    def getTimestamp(self) -> int: ...
    @staticmethod
    def isValid(hexString: AnyStr) -> bool: ...
    def putToByteBuffer(self, buffer: ByteBuffer) -> None: ...
    def toHexString(self) -> AnyStr: ...

class Symbol(Object):
    def __init__(self, symbol: AnyStr) -> None: ...
    def getSymbol(self) -> AnyStr: ...



from typing import Any, List

from dev.coatl.helper.types import AnyStr
from java.lang import Enum, Object
from java.security import Principal
from java.time import Instant
from java.util.concurrent import TimeUnit

class AttributeView:
    def name(self) -> AnyStr: ...

class BasicFileAttributes:
    def creationTime(self) -> FileTime: ...
    def fileKey(self) -> Object: ...
    def isDirectory(self) -> bool: ...
    def isOther(self) -> bool: ...
    def isRegularFile(self) -> bool: ...
    def isSymbolicLink(self) -> bool: ...
    def lastAccessTime(self) -> FileTime: ...
    def lastModifiedTime(self) -> FileTime: ...
    def size(self) -> long: ...

class FileAttribute:
    def name(self) -> AnyStr: ...
    def value(self) -> Any: ...

class FileAttributeView(AttributeView):
    def name(self) -> AnyStr: ...

class FileTime(Object):
    def compareTo(self, other: FileTime) -> int: ...
    @staticmethod
    def fromMillis(value: long) -> FileTime: ...
    def to(self, unit: TimeUnit) -> long: ...
    def toInstant(self) -> Instant: ...
    def toMillis(self) -> long: ...

class PosixFilePermission(Enum):
    GROUP_EXECUTE: PosixFilePermission
    GROUP_READ: PosixFilePermission
    GROUP_WRITE: PosixFilePermission
    OTHERS_EXECUTE: PosixFilePermission
    OTHERS_READ: PosixFilePermission
    OTHERS_WRITE: PosixFilePermission
    OWNER_EXECUTE: PosixFilePermission
    OWNER_READ: PosixFilePermission
    OWNER_WRITE: PosixFilePermission
    @staticmethod
    def values() -> List[PosixFilePermission]: ...

class UserPrincipal(Principal):
    def equals(self, another: Object) -> bool: ...
    def getName(self) -> AnyStr: ...
    def hashCode(self) -> int: ...
    def toString(self) -> AnyStr: ...

class FileStoreAttributeView(AttributeView):
    def name(self) -> AnyStr: ...



from typing import Any, List

from java.lang import Enum, Number, Object

class BigDecimal(Number):
    ONE: BigDecimal
    TEN: BigDecimal
    ZERO: BigDecimal
    def __init__(self, *args: Any) -> None: ...
    def doubleValue(self) -> float: ...
    def floatValue(self) -> float: ...
    def intValue(self) -> int: ...
    def longValue(self) -> long: ...

class BigInteger(Number):
    ONE: BigInteger
    TEN: BigInteger
    TWO: BigInteger
    ZERO: BigInteger
    def __init__(self, *args: Any) -> None: ...
    def doubleValue(self) -> float: ...
    def floatValue(self) -> float: ...
    def intValue(self) -> int: ...
    def longValue(self) -> long: ...

class MathContext(Object):
    def __init__(self, *args: Any) -> None: ...
    def getPrecision(self) -> int: ...
    def getRoundingMode(self) -> RoundingMode: ...

class RoundingMode(Enum):
    CEILING: RoundingMode
    DOWN: RoundingMode
    FLOOR: RoundingMode
    HALF_DOWN: RoundingMode
    HALF_EVEN: RoundingMode
    HALF_UP: RoundingMode
    UNNECESSARY: RoundingMode
    UP: RoundingMode
    @staticmethod
    def values() -> List[RoundingMode]: ...



from typing import Any

from dev.coatl.helper.types import AnyStr
from java.lang import Object

class ProgressListener:
    def setIndeterminate(self, arg: bool) -> None: ...
    def setNote(self, note: AnyStr) -> None: ...
    def setProgress(self, val: int) -> None: ...
    def setProgressMax(self, max_: int) -> None: ...

class TaskProgressListener(ProgressListener):
    def isCanceled(self) -> bool: ...
    def setIndeterminate(self, arg: bool) -> None: ...
    def setNote(self, note: AnyStr) -> None: ...
    def setProgress(self, val: int) -> None: ...
    def setProgressMax(self, max_: int) -> None: ...

class TaskProgressState(Object, ProgressListener):
    def __init__(self, *args: Any) -> None: ...
    def applyTo(self, listener: ProgressListener) -> None: ...
    def getNote(self) -> AnyStr: ...
    def getProgress(self) -> int: ...
    def getProgressMax(self) -> int: ...
    def getResult(self) -> Object: ...
    def getTaskUID(self) -> AnyStr: ...
    def isFinished(self) -> bool: ...
    def isIndeterminant(self) -> bool: ...
    def setFinished(self, finished: bool) -> None: ...
    def setIndeterminate(self, arg: bool) -> None: ...
    def setNote(self, note: AnyStr) -> None: ...
    def setProgress(self, val: int) -> None: ...
    def setProgressMax(self, max_: int) -> None: ...
    def setResult(self, result: Object) -> None: ...



from typing import Any, List

from com.inductiveautomation.ignition.common.xmlserialization import ClassNameResolver
from com.inductiveautomation.ignition.common.xmlserialization.encoding import (
    AttributeEncoder,
)
from com.inductiveautomation.ignition.common.xmlserialization.serialization.equalitydelegates import (
    EqualityDelegate,
)
from dev.coatl.helper.types import AnyStr as AnyStr
from java.lang import Class, Object

class Element(Object):
    def __init__(self, *args: Any) -> None: ...
    def addChild(self, element: Element) -> None: ...
    def getAttributes(self) -> List[Element.Attribute]: ...
    def getBody(self) -> Any: ...
    def getChildCount(self) -> int: ...
    def getChildren(self) -> List[Element]: ...
    def getName(self) -> AnyStr: ...
    def getObject(self) -> Object: ...
    def getSubName(self) -> AnyStr: ...
    def isSkipRefTracking(self) -> bool: ...
    def setAttribute(self, *args: Any) -> None: ...
    def setBody(self, body: Any) -> None: ...
    def setSkipRefTrack(self, skipRefTracking: bool) -> None: ...

    class Attribute(Object):
        def __init__(self, name: AnyStr, value: AttributeEncoder) -> None: ...
        def getName(self) -> AnyStr: ...
        def getValue(self) -> AttributeEncoder: ...

class SerializationDelegate:
    def isSkipReferenceTracking(self) -> bool: ...
    def serialize(self, context: XMLSerializationContext, obj: Any) -> Element: ...

class XMLSerializationContext(Object):
    def __init__(self, serializer: XMLSerializer) -> None: ...
    def getClassNameMap(self) -> ClassNameResolver: ...
    def getCleanCopy(self, type_: Class) -> Object: ...
    def getRefForElement(self, elm: Element) -> int: ...
    def registerEqualityDelegate(
        self, clazz: Class, delegate: EqualityDelegate
    ) -> None: ...
    def safeEquals(self, foo: Object, bar: Object) -> bool: ...
    def serialize(self, obj: Object) -> Element: ...

class XMLSerializer(Object):
    def __init__(self) -> None: ...
    def addObject(self, obj: Object) -> None: ...
    def addRootAttribute(self, key: AnyStr, value: AnyStr) -> None: ...
    def addSerializationDelegate(
        self, clazz: Class, delegate: SerializationDelegate
    ) -> None: ...



from copy import PyStringMap
from typing import Any, List, Mapping, Optional, Set

from com.codahale.metrics import Timer
from com.inductiveautomation.ignition.common.script.hints import ScriptFunctionHint
from dev.coatl.helper.types import AnyStr
from java.io import OutputStream
from java.lang import Class, Object
from java.util import UUID
from org.python.core import PyObject, PySystemState

class ScriptFunction:
    def invoke(self, *args: Any) -> PyObject: ...

class ScriptManager(Object):
    def __init__(self, contextName: AnyStr, pathToExternalLibs: AnyStr) -> None: ...
    def addGlobalVariable(self, name: AnyStr, value: PyObject) -> None: ...
    def addScriptModule(self, *args: Any) -> None: ...
    def addStaticFields(self, path: AnyStr, clazz: Class) -> None: ...
    def addStdErrStream(self, os: OutputStream) -> None: ...
    def addStdOutStream(self, os: OutputStream) -> None: ...
    @staticmethod
    def asynchInit(pathToExternalLibs: Optional[AnyStr] = ...) -> None: ...
    def beginCompileTimer(self) -> Timer.Context: ...
    def clearAppModule(self) -> None: ...
    def clearModule(self, moduleName: AnyStr) -> None: ...
    def clearProjectScriptModules(self) -> None: ...
    def clearThirdPartyModules(self) -> None: ...
    def compileFunction(self, *args: Any) -> ScriptFunction: ...
    def createLocalsMap(self) -> PyStringMap: ...
    @staticmethod
    def createUtf8PySystemState(
        stdOut: OutputStream, stdErr: OutputStream
    ) -> PySystemState: ...
    @staticmethod
    def executingScripts() -> Set[ScriptManager.ExecutionInfo]: ...
    def getCompileTimer(self) -> Timer: ...
    def getExecutionTimer(self) -> Timer: ...
    def getGlobals(self) -> PyStringMap: ...
    def getHintsMap(self) -> Mapping[AnyStr, List[ScriptFunctionHint]]: ...
    def getModules(self) -> PyStringMap: ...
    def getUUID(self) -> UUID: ...
    @staticmethod
    def interrupt(threadId: long) -> None: ...
    @staticmethod
    def main(*args: AnyStr) -> None: ...
    def removeStdErrStream(self, os: OutputStream) -> None: ...
    def removeStdOutStream(self, os: OutputStream) -> None: ...
    def runCode(self, *args: Any) -> None: ...
    def runFunction(self, *args: Any) -> PyObject: ...
    def setContextName(self, name: AnyStr) -> None: ...
    def setPaused(self, paused: bool) -> None: ...
    def shutdown(self) -> None: ...
    def validatePackageName(self, newName: AnyStr) -> None: ...

    class ExecutionInfo(Object):
        description: AnyStr
        startTime: long
        threadId: long



from typing import Any, List, Optional, Union

from com.inductiveautomation.ignition.common.model.values import (
    BasicQualifiedValue,
    QualityCode,
)
from com.inductiveautomation.ignition.common.opc import BasicOPCBrowseElement
from com.inductiveautomation.ignition.common.script.builtin import AbstractOPCUtilities
from com.inductiveautomation.ignition.common.script.builtin.ialabs import OPCBrowseTag
from dev.coatl.helper.types import AnyStr

BrowseServerResult = List[Union[BasicOPCBrowseElement, AbstractOPCUtilities.PyOPCTag]]

def browse(
    opcServer: AnyStr, device: AnyStr, folderPath: AnyStr, opcItemPath: AnyStr
) -> List[OPCBrowseTag]: ...
def browseServer(opcServer: AnyStr, nodeId: AnyStr) -> BrowseServerResult: ...
def browseSimple(
    opcServer: AnyStr, device: AnyStr, folderPath: AnyStr, opcItemPath: AnyStr
) -> List[OPCBrowseTag]: ...
def getServerState(opcServer: AnyStr) -> Optional[AnyStr]: ...
def getServers(includeDisabled: Optional[bool] = ...) -> List[AnyStr]: ...
def isServerEnabled(serverName: AnyStr) -> bool: ...
def readValue(opcServer: AnyStr, itemPath: AnyStr) -> BasicQualifiedValue: ...
def readValues(
    opcServer: AnyStr, itemPaths: List[AnyStr]
) -> List[BasicQualifiedValue]: ...
def setServerEnabled(serverName: AnyStr, enabled: bool) -> None: ...
def writeValue(opcServer: AnyStr, itemPath: AnyStr, value: Any) -> QualityCode: ...
def writeValues(
    opcServer: AnyStr, itemPaths: List[AnyStr], values: List[Any]
) -> List[QualityCode]: ...



from typing import Any, Dict, List, Optional

from dev.coatl.helper.types import AnyStr
from java.lang import Enum, Object
from java.time import Duration
from java.time.format import ResolverStyle
from java.util import Locale

class TemporalAccessor:
    def get(self, field: TemporalField) -> int: ...
    def getLong(self, field: TemporalField) -> long: ...
    def isSupported(self, field: TemporalField) -> bool: ...
    def query(self, query: TemporalQuery) -> Any: ...
    def range(self, field: TemporalField) -> ValueRange: ...

class TemporalAdjuster:
    def adjustInto(self, temporal: Temporal) -> Temporal: ...

class TemporalField:
    def adjustInto(self, temporal: Any, newValue: long) -> Temporal: ...
    def getBaseUnit(self) -> TemporalUnit: ...
    def getDisplayName(self, locale: Locale) -> AnyStr: ...
    def getFrom(self, temporal: TemporalAccessor) -> long: ...
    def getRangeUnit(self) -> TemporalUnit: ...
    def isDateBased(self) -> bool: ...
    def isSupportedBy(self, temporal: TemporalAccessor) -> bool: ...
    def isTimeBased(self) -> bool: ...
    def range(self) -> ValueRange: ...
    def rangeRefinedBy(self, temporal: TemporalAccessor) -> ValueRange: ...
    def resolve(
        self,
        fieldValues: Dict[TemporalField, long],
        partialTemporal: TemporalAccessor,
        resolverStyle: ResolverStyle,
    ) -> TemporalAccessor: ...
    def toString(self) -> AnyStr: ...

class TemporalQuery:
    def queryFrom(self, temporal: TemporalAccessor) -> Any: ...

class TemporalUnit:
    def addTo(self, temporal: Temporal, amount: long) -> Temporal: ...
    def between(
        self, temporal1Inclusive: Temporal, temporal2Exclusive: Temporal
    ) -> Temporal: ...
    def isSupportedBy(self, temporal: Temporal) -> bool: ...
    def getDuration(self) -> Duration: ...
    def isDateBased(self) -> bool: ...
    def isDurationEstimated(self) -> bool: ...
    def isTimeBased(self) -> bool: ...
    def toString(self) -> AnyStr: ...

class Temporal(TemporalAccessor):
    def minus(self, amount: long, unit: Optional[TemporalUnit] = ...) -> Temporal: ...
    def plus(self, amount: long, unit: Optional[TemporalUnit] = ...) -> Temporal: ...
    def until(self, endExclusive: Temporal, unit: TemporalUnit) -> long: ...

class ChronoUnit(Enum, TemporalUnit):
    CENTURIES: ChronoUnit
    DAYS: ChronoUnit
    DECADES: ChronoUnit
    ERAS: ChronoUnit
    FOREVER: ChronoUnit
    MICROS: ChronoUnit
    MILLENNIA: ChronoUnit
    MILLIS: ChronoUnit
    MINUTES: ChronoUnit
    MONTHS: ChronoUnit
    NANOS: ChronoUnit
    SECONDS: ChronoUnit
    HALF_DAYS: ChronoUnit
    HOURS: ChronoUnit
    WEEKS: ChronoUnit
    YEARS: ChronoUnit
    def addTo(self, temporal: Temporal, amount: long) -> Temporal: ...
    def between(
        self, temporal1Inclusive: Temporal, temporal2Exclusive: Temporal
    ) -> Temporal: ...
    def getDuration(self) -> Duration: ...
    def isDateBased(self) -> bool: ...
    def isDurationEstimated(self) -> bool: ...
    def isTimeBased(self) -> bool: ...
    @staticmethod
    def values() -> List[ChronoUnit]: ...

class ValueRange(Object):
    def checkValidIntValue(self, value: long, field: TemporalField) -> int: ...
    def checkValidValue(self, value: long, field: TemporalField) -> long: ...
    def getLargestMinimum(self) -> long: ...
    def getMaximum(self) -> long: ...
    def getMinimum(self) -> long: ...
    def getSmallestMaximum(self) -> long: ...
    def isFixed(self) -> bool: ...
    def isIntValue(self) -> bool: ...
    def isValidIntValue(self, value: long) -> bool: ...
    def isValidValue(self, value: long) -> bool: ...
    @staticmethod
    def of(*args: Any) -> ValueRange: ...



from typing import Any, List

from com.inductiveautomation.ignition.common.functional import FragileRunnable
from dev.coatl.helper.types import AnyStr
from java.lang import Object
from java.util import Locale
from java.util.function import Consumer

class MessageInterface:
    def addMessageReceiver(self, protocol: AnyStr, rcv: MessageReceiver) -> None: ...
    def sendCall(self, protocol: AnyStr, scope: int, msg: Any) -> Any: ...
    def sendMessage(self, protocol: AnyStr, scope: int, msg: Any) -> None: ...

class MessageReceiver:
    def receiveCall(self, msg: Any) -> Any: ...

class UIResponse(Object):
    errors: List[AnyStr]
    infos: List[AnyStr]
    locale: Locale
    warns: List[AnyStr]
    def __init__(self, locale: Locale) -> None: ...
    def attempt(self, method: FragileRunnable) -> None: ...
    def error(self, message: AnyStr, *args: Object) -> None: ...
    def getErrors(self) -> List[AnyStr]: ...
    def getInfos(self) -> List[AnyStr]: ...
    def getLocale(self) -> Locale: ...
    def getWarns(self) -> List[AnyStr]: ...
    def info(self, message: AnyStr, *args: Object) -> None: ...
    def warn(self, message: AnyStr, *args: Object) -> None: ...
    @staticmethod
    def wrap(locale: Locale, fx: Consumer) -> UIResponse: ...



from typing import Iterable, List, Optional, Set

from com.inductiveautomation.ignition.common.project.resource import (
    ProjectResource,
    ProjectResourceId,
    ResourceSignature,
)
from com.inductiveautomation.ignition.gateway.project import ResourceFilter
from dev.coatl.helper.types import AnyStr
from java.lang import Enum, Object

class Project:
    def addProjectResourceListener(self, listener: ProjectResourceListener) -> None: ...

class ProjectResourceListener:
    def getResourceFilter(self) -> ResourceFilter: ...
    def manifestChanged(
        self,
        projectName: AnyStr,
        operation: List[ChangeOperation.ManifestChangeOperation],
    ) -> None: ...
    def onAfterChanges(self) -> None: ...
    def onBeforeChanges(self) -> None: ...
    def resourcesCreated(
        self,
        projectName: AnyStr,
        resources: List[ChangeOperation.CreateResourceOperation],
    ) -> None: ...
    def resourcesDeleted(
        self,
        projectName: AnyStr,
        resources: List[ChangeOperation.DeleteResourceOperation],
    ) -> None: ...
    def resourcesModified(
        self,
        projectName: AnyStr,
        resources: List[ChangeOperation.ModifyResourceOperation],
    ) -> None: ...

class ChangeOperation(Object):
    @staticmethod
    def changeOpsToIdSet(changes: List[ChangeOperation]) -> Set[ProjectResourceId]: ...
    def getOperationType(self) -> ChangeOperation.OperationType: ...
    def getProjectName(self) -> AnyStr: ...
    @staticmethod
    def getResourceFromChange(op: ChangeOperation) -> ProjectResource: ...
    @staticmethod
    def getResourceIdFromChange(op: ChangeOperation) -> ProjectResourceId: ...
    @staticmethod
    def newCreateOp(
        resource: ProjectResource,
    ) -> ChangeOperation.CreateResourceOperation: ...
    @staticmethod
    def newDeleteOp(
        resourceSignature: ResourceSignature,
    ) -> ChangeOperation.DeleteResourceOperation: ...
    @staticmethod
    def newManifestChangeOp(
        projectName: AnyStr,
        manifest: ProjectManifest,
        baseHashCode: Optional[int] = ...,
    ) -> ChangeOperation.ManifestChangeOperation: ...
    @staticmethod
    def newModifyOp(
        resource: ProjectResource, baseSignature: ResourceSignature
    ) -> ModifyResourceOperation: ...

    class CreateResourceOperation(Object):
        def getResource(self) -> ProjectResource: ...
        def getResourceId(self) -> ProjectResourceId: ...

    class DeleteResourceOperation(Object):
        def getResourceId(self) -> ProjectResourceId: ...
        def getResourceSignature(self) -> ResourceSignature: ...

    class ManifestChangeOperation(Object):
        def getBaseHashCode(self) -> int: ...
        def getManifest(self) -> ProjectManifest: ...
        def getProjectName(self) -> AnyStr: ...

    class ModifyResourceOperation(Object):
        def getBaseSignature(self) -> ResourceSignature: ...
        def getResource(self) -> ProjectResource: ...
        def getResourceId(self) -> ProjectResourceId: ...

    class OperationType(Enum):
        @staticmethod
        def values() -> Iterable[ChangeOperation.OperationType]: ...

    class ResourceChangeOperation(Object):
        def getProjectName(self) -> AnyStr: ...
        def getResourceId(self) -> ProjectResourceId: ...

class ProjectManifest(Object):
    def __init__(
        self,
        title: AnyStr,
        description: AnyStr,
        enabled: bool,
        inheritable: bool,
        parent: AnyStr,
    ) -> None: ...



from com.inductiveautomation.ignition.common.tags.model import TagPath
from com.inductiveautomation.ignition.common.tags.paths import AbstractTagPath

class SimplifiedTagPath(AbstractTagPath):
    def __init__(self, delegate: TagPath) -> None: ...



from typing import Any, Iterable, Union

from com.inductiveautomation.ignition.common.gson import JsonObject
from dev.coatl.helper.types import AnyStr
from java.lang import Enum, Object
from java.util import Date

class QualifiedValue:
    def derive(self, arg: Union[None, QualityCode, AnyStr] = ...) -> QualifiedValue: ...
    def getQuality(self) -> QualityCode: ...
    def getTimestamp(self) -> Date: ...
    def getValue(self) -> Object: ...

class Quality:
    def getDescription(self) -> AnyStr: ...
    def getLevel(self) -> Quality.Level: ...
    def getName(self) -> AnyStr: ...
    def getQualityCode(self) -> QualityCode: ...
    def isGood(self) -> bool: ...

    class Level(Enum):
        Bad: int
        Good: int
        Unknown: int
        @staticmethod
        def values() -> Iterable[Quality.Level]: ...

class QualityCode(Object):
    Bad: QualityCode
    Bad_AccessDenied: QualityCode
    Bad_AggregateNotFound: QualityCode
    Bad_DatabaseNotConnected: QualityCode
    Bad_Disabled: QualityCode
    Bad_Failure: QualityCode
    Bad_GatewayCommOff: QualityCode
    Bad_LicenseExceeded: QualityCode
    Bad_NotConnected: QualityCode
    Bad_NotFound: QualityCode
    Bad_OutOfRange: QualityCode
    Bad_ReadOnly: QualityCode
    Bad_Stale: QualityCode
    Bad_ReferenceNotFound: QualityCode
    Bad_TrialExpired: QualityCode
    Bad_Unauthorized: QualityCode
    Bad_Unsupported: QualityCode
    Error: QualityCode
    Error_Configuration: QualityCode
    Error_CycleDetected: QualityCode
    Error_DatabaseQuery: QualityCode
    Error_Exception: QualityCode
    Error_ExpressionEval: QualityCode
    Error_Formatting: QualityCode
    Error_InvalidPathSyntax: QualityCode
    Error_IO: QualityCode
    Error_ScriptEval: QualityCode
    Error_TagExecution: QualityCode
    Error_TimeoutExpired: QualityCode
    Error_TypeConversion: QualityCode
    Good: QualityCode
    Good_Backfill: QualityCode
    Good_Initial: QualityCode
    Good_Overload: QualityCode
    Good_Provisional: QualityCode
    Good_Unspecified: QualityCode
    Good_WritePending: QualityCode
    Uncertain: QualityCode
    Uncertain_LastKnownValue: QualityCode
    Uncertain_InitialValue: QualityCode
    Uncertain_DataSubNormal: QualityCode
    Uncertain_EngineeringUnitsExceeded: QualityCode
    Uncertain_IncompleteOperation: QualityCode
    def __init__(self, *args: Any) -> None: ...
    def derive(self, diagnosticMessage: AnyStr) -> QualityCode: ...
    def getCode(self) -> int: ...
    @staticmethod
    def getCodeName(code: Union[int, QualityCode]) -> AnyStr: ...
    @staticmethod
    def getCodesJson() -> JsonObject: ...
    def getDiagnosticMessage(self) -> AnyStr: ...
    def getLevel(self) -> QualityCode.Level: ...
    def getName(self) -> AnyStr: ...
    def isBad(self) -> bool: ...
    def isBadOrError(self) -> bool: ...
    def isError(self) -> bool: ...
    def isGood(self) -> bool: ...
    def isNotGood(self) -> bool: ...
    def isUncertain(self) -> bool: ...

    class Level(Enum):
        def code(self, userCode: int) -> int: ...
        @staticmethod
        def values() -> Iterable[QualityCode.Level]: ...

class BasicQualifiedValue(QualifiedValue, Object):
    quality: QualityCode
    timestamp: Date
    value: Object
    def __init__(self, *args: Any) -> None: ...
    def BAD(self) -> BasicQualifiedValue: ...
    def CONFIG_ERROR(self) -> BasicQualifiedValue: ...
    def DISABLED(self) -> BasicQualifiedValue: ...
    def EXPRESSION_EVAL_ERROR(self) -> BasicQualifiedValue: ...
    def INITIAL_VALUE(self) -> BasicQualifiedValue: ...
    def NOT_CONNECTED(self) -> BasicQualifiedValue: ...
    def NOT_FOUND(self) -> BasicQualifiedValue: ...
    def REFERENCE_NOT_FOUND(self) -> BasicQualifiedValue: ...
    def STALE(self) -> BasicQualifiedValue: ...
    def TRANSFORM_ERROR(self) -> BasicQualifiedValue: ...
    def TYPE_CONVERSION(self) -> BasicQualifiedValue: ...
    def UNKNOWN(self) -> BasicQualifiedValue: ...
    def UNSUPPORTED(self) -> BasicQualifiedValue: ...
    def clone(self) -> BasicQualifiedValue: ...
    def derive(self, arg: Union[None, QualityCode, AnyStr] = ...) -> QualifiedValue: ...
    @staticmethod
    def fromObject(obj: Object) -> QualifiedValue: ...
    def getQuality(self) -> QualityCode: ...
    def getTimestamp(self) -> Date: ...
    def getValue(self) -> Object: ...
    def setQuality(self, code: QualityCode) -> None: ...
    def setTimestamp(self, timestamp: Date) -> None: ...
    def setValue(self, value: Object) -> None: ...
    @staticmethod
    def unwrap(obj: Object) -> Object: ...
    @staticmethod
    def updateTimestamp(copy: QualifiedValue) -> QualifiedValue: ...
    @staticmethod
    def valueOf(obj: Object) -> Object: ...



from typing import Any, Set, Union

from dev.coatl.helper.types import AnyStr
from java.lang import Class, Object
from java.util import Collection, Date, Map
from org.bson.codecs.configuration import CodecRegistry
from org.bson.types import ObjectId

class BSONObject:
    def containsField(self, s: AnyStr) -> bool: ...
    def get(self, key: AnyStr) -> Object: ...
    def keySet(self) -> Set[AnyStr]: ...
    def put(self, k: AnyStr, v: Object) -> Object: ...
    def putAll(self, arg: Union[BSONObject, Map]) -> None: ...
    def removeField(self, key: AnyStr) -> Object: ...
    def toMap(self) -> Map: ...

class BsonValue(Object):
    def __init__(self) -> None: ...

class BsonDocument(BsonValue):
    def __init__(self, *args: Any) -> None: ...

class Document(Object):
    def __init__(self, *args: Any) -> None: ...
    def append(self, key: AnyStr, value: Object) -> Document: ...
    def clear(self) -> None: ...
    def containsKey(self, key: Object) -> bool: ...
    def containsValue(self, value: Object) -> bool: ...
    def entrySet(self) -> Set[Any]: ...
    def get(self, *args: Any) -> Any: ...
    def getBoolean(self, *args: Any) -> bool: ...
    def getDate(self, key: Object) -> Date: ...
    def getDouble(self, key: Object) -> float: ...
    def getInteger(self, key: Object) -> int: ...
    def getLong(self, key: Object) -> long: ...
    def getObjectId(self, key: Object) -> ObjectId: ...
    def getString(self, key: Object) -> AnyStr: ...
    def isEmpty(self) -> bool: ...
    def keySet(self) -> Set[AnyStr]: ...
    @staticmethod
    def parse(*args: Any) -> Document: ...
    def put(self, key: AnyStr, value: Object) -> Object: ...
    def putAll(self, map: Map) -> None: ...
    def remove(self, key: Object) -> Object: ...
    def size(self) -> int: ...
    def toBsonDocument(
        self, documentClass: Class, codecRegistry: CodecRegistry
    ) -> BsonDocument: ...
    def toJson(self, *args: Any) -> AnyStr: ...
    def values(self) -> Collection: ...



from typing import Any, List, Optional

from dev.coatl.helper.types import AnyStr
from system.bacnet.enumerated import ObjectType, PropertyIdentifier

def readRaw(
    deviceName: AnyStr,
    objectType: ObjectType,
    objectId: int,
    propertyId: PropertyIdentifier,
    propertyArrayIndex: Optional[int] = ...,
) -> List[Any]: ...
def readRawMultiple(
    deviceName: AnyStr,
    objectTypes: List[ObjectType],
    objectIds: List[int],
    propertyIds: List[PropertyIdentifier],
) -> List[Any]: ...
def synchronizeTime(deviceName: AnyStr) -> None: ...
def synchronizeTimeUtc(deviceName: AnyStr) -> None: ...
def writeRaw(
    deviceName: AnyStr,
    objectType: ObjectType,
    objectId: int,
    propertyId: PropertyIdentifier,
    value: Any,
    priority: int = ...,
    propertyArrayIndex: Optional[int] = ...,
) -> None: ...
def writeRawMultiple(
    deviceName: AnyStr,
    objectTypes: List[ObjectType],
    objectIds: List[int],
    propertyIds: List[PropertyIdentifier],
    values: List[Any],
    priorities: Optional[List[int]] = ...,
    propertyArrayIndices: Optional[List[int]] = ...,
) -> None: ...
def writeWithPriority(
    deviceName: AnyStr, objectType: int, objectId: int, value: Any, priority: int
) -> None: ...

# Names in __all__ with no definition:
#   enumerated
#   enums



from typing import Any

from dev.coatl.helper.types import AnyStr
from java.lang import Object
from org.python.core import PyObject

class SerialScriptModule(Object):
    def __init__(self) -> None: ...
    @staticmethod
    def setTrialExpired(trialExpired: bool) -> None: ...

    class PortManager:
        def __init__(self, *args: Any) -> None: ...
        def __enter__(self) -> None: ...
        def __exit__(
            self, exc_type: object, exc_val: object, exc_tb: object
        ) -> None: ...

    class SerialConfigurator:
        def setBitRate(self, value: int) -> SerialScriptModule.SerialConfigurator: ...
        def setDataBits(self, value: int) -> SerialScriptModule.SerialConfigurator: ...
        def setFlowControl(
            self, value: bool
        ) -> SerialScriptModule.SerialConfigurator: ...
        def setHandshake(self, value: int) -> SerialScriptModule.SerialConfigurator: ...
        def setHardwareFlowControl(
            self, value: int
        ) -> SerialScriptModule.SerialConfigurator: ...
        def setParity(self, value: int) -> SerialScriptModule.SerialConfigurator: ...
        def setStopBits(self, value: int) -> SerialScriptModule.SerialConfigurator: ...

    class SerialPortWrapper(PyObject):
        def __init__(self, port: AnyStr, serialPort: Any) -> None: ...
        def readBytes(
            self, port: AnyStr, numberOfBytes: int, timeout: int = ...
        ) -> bytearray: ...
        def readBytesAsString(
            self,
            port: AnyStr,
            numberOfBytes: int,
            timeout: int = ...,
            encoding: AnyStr = ...,
        ) -> AnyStr: ...
        def readLine(
            self,
            port: AnyStr,
            timeout: int = ...,
            encoding: AnyStr = ...,
            crlfRequired: bool = ...,
        ) -> AnyStr: ...
        def readUntil(
            self,
            port: AnyStr,
            delimiter: str,
            includeDelimiter: bool,
            timeout: int = ...,
        ) -> AnyStr: ...
        def sendBreak(self, port: AnyStr, millis: long) -> None: ...
        def write(
            self, port: AnyStr, toWrite: bytearray, encoding: AnyStr = ...
        ) -> None: ...
        def writeBytes(
            self, port: AnyStr, toWrite: bytearray, timeout: int = ...
        ) -> None: ...



from typing import Any, Optional

from dev.coatl.helper.types import AnyStr
from java.awt.geom import Dimension2D, Point2D
from java.lang import Object
from java.util import EventObject

class LayoutManager:
    def addLayoutComponent(self, name: AnyStr, comp: Component) -> None: ...
    def layoutContainer(self, parent: Container) -> None: ...
    def minimumLayoutSize(self, parent: Container) -> Dimension: ...
    def preferredLayoutSize(self, parent: Container) -> Dimension: ...
    def removeLayoutComponent(self, comp: Component) -> None: ...

class AWTEvent(EventObject):
    def __init__(self, source: Object, id: int) -> None: ...
    def getID(self) -> int: ...
    def paramString(self) -> AnyStr: ...
    def setSource(self, newSource: Object) -> None: ...

class Color(Object):
    def __init__(self, *args: Any) -> None: ...

class Component(Object):
    def imageUpdate(
        self, img: Image, infoflags: int, x: int, y: int, width: int, height: int
    ) -> bool: ...

class Container(Component):
    def add(self, *args: Any) -> Optional[Component]: ...

class Dimension(Dimension2D):
    height: int
    width: int
    def __init__(self, *args: Any) -> None: ...
    def getHeight(self) -> float: ...
    def getSize(self) -> Dimension: ...
    def getWidth(self) -> float: ...
    def setSize(self, *args: Any) -> None: ...

class Image(Object):
    def flush(self) -> None: ...
    def getAccelerationPriority(self) -> float: ...
    def setAccelerationPriority(self, priority: float) -> None: ...

class Point(Point2D):
    x: int
    y: int
    def __init__(self, *args: Any) -> None: ...
    def getLocation(self) -> Point: ...
    def getX(self) -> float: ...
    def getY(self) -> float: ...
    def move(self, x: int, y: int) -> None: ...
    def setLocation(self, *args: Any) -> None: ...
    def translate(self, dx: int, dy: int) -> None: ...

class Toolkit(Object):
    def __init__(self) -> None: ...
    def beep(self) -> None: ...
    @staticmethod
    def getDefaultToolkit() -> Toolkit: ...

class Window(Container):
    def __init__(self, *args: Any) -> None: ...

class Frame(Window):
    def __init__(self, *args: Any) -> None: ...

class Graphics(Object):
    def create(self) -> Graphics: ...

class GridLayout(Object, LayoutManager):
    def __init__(
        self,
        rows: Optional[int] = ...,
        cols: Optional[int] = ...,
        hgap: Optional[int] = ...,
        vgap: Optional[int] = ...,
    ) -> None: ...
    def addLayoutComponent(self, name: AnyStr, comp: Component) -> None: ...
    def getColumns(self) -> int: ...
    def getHgap(self) -> int: ...
    def getRows(self) -> int: ...
    def getVgap(self) -> int: ...
    def layoutContainer(self, parent: Container) -> None: ...
    def minimumLayoutSize(self, parent: Container) -> Dimension: ...
    def preferredLayoutSize(self, parent: Container) -> Dimension: ...
    def removeLayoutComponent(self, comp: Component) -> None: ...
    def setColumns(self, cols: int) -> None: ...
    def setHgap(self, hgap: int) -> None: ...
    def setRows(self, rows: int) -> None: ...
    def setVgap(self, vgap: int) -> None: ...



from typing import Any, Dict, List, Optional, Type, Union

from com.inductiveautomation.ignition.common import Dataset
from com.inductiveautomation.ignition.common.script.builtin import DatasetUtilities
from dev.coatl.helper.types import AnyNum, AnyStr
from java.util import Date, Locale

ColType = Union[AnyNum, AnyStr, Date]

def addColumn(
    dataset: Dataset,
    colIndex: int,
    col: List[Any],
    colName: AnyStr,
    colType: Type[ColType],
) -> Dataset: ...
def addRow(dataset: Dataset, rowIndex: int, row: List[Any]) -> Dataset: ...
def addRows(dataset: Dataset, rowIndex: int, rows: List[List[Any]]) -> Dataset: ...
def appendDataset(dataset1: Dataset, dataset2: Dataset) -> Dataset: ...
def clearDataset(dataset: Dataset) -> Dataset: ...
def dataSetToHTML(showHeaders: bool, dataset: Dataset, title: AnyStr) -> AnyStr: ...
def deleteRow(dataset: Dataset, rowIndex: int) -> Dataset: ...
def deleteRows(dataset: Dataset, rowIndices: List[int]) -> Dataset: ...
def exportCSV(filename: AnyStr, showHeaders: bool, dataset: Dataset) -> AnyStr: ...
def exportExcel(
    filename: AnyStr,
    showHeaders: bool,
    dataset: Union[Dataset, List[Dataset]],
    nullsEmpty: bool = ...,
) -> AnyStr: ...
def exportHTML(
    filename: AnyStr, showHeaders: bool, dataset: Dataset, title: AnyStr
) -> AnyStr: ...
def filterColumns(
    dataset: Dataset, columns: Union[List[AnyStr], List[int]]
) -> Dataset: ...
def formatDates(
    dataset: Dataset, dateFormat: AnyStr, locale: Optional[Locale] = ...
) -> Dataset: ...
def fromCSV(csv: AnyStr) -> Dataset: ...
def getColumnHeaders(dataset: Dataset) -> List[AnyStr]: ...
def setValue(
    dataset: Dataset, rowIndex: int, columnNameOrIndex: Union[AnyStr, int], value: Any
) -> Dataset: ...
def sort(
    dataset: Dataset,
    keyColumn: Union[AnyStr, int],
    ascending: bool = ...,
    naturalOrdering: bool = ...,
) -> Dataset: ...
def toCSV(
    dataset: Dataset,
    showHeaders: bool = ...,
    forExport: bool = ...,
    localized: bool = ...,
) -> AnyStr: ...
def toDataSet(*args: Any) -> Dataset: ...
def toExcel(
    showHeaders: bool,
    dataset: List[Dataset],
    nullsEmpty: bool = ...,
    sheetNames: Optional[List[AnyStr]] = ...,
) -> Any: ...
def toPyDataSet(dataset: Dataset) -> DatasetUtilities.PyDataSet: ...
def updateRow(
    dataset: Dataset, rowIndex: int, changes: Dict[AnyStr, Any]
) -> Dataset: ...



from typing import Any, Dict, List, Optional, Tuple, Union

from com.inductiveautomation.factorypmi.application import FPMIApp, FPMIWindow
from com.inductiveautomation.factorypmi.application.script import PyComponentWrapper
from com.inductiveautomation.ignition.common.model.values import QualityCode
from dev.coatl.helper.types import AnyStr
from java.awt import Color, Component, Graphics
from java.awt.event import ActionEvent, ComponentEvent, MouseEvent
from java.awt.image import BufferedImage
from java.awt.print import PageFormat
from java.lang import Number, Object
from java.util import EventObject
from javax.swing import JComponent, JFrame, JPopupMenu
from org.python.core import PyObject, PySequence, PyTuple

class INavUtilities:
    def centerWindow(self, arg: Union[FPMIWindow, AnyStr]) -> None: ...
    def closeParentWindow(self, event: EventObject) -> None: ...
    def closeWindow(self, arg: Union[FPMIWindow, AnyStr]) -> None: ...
    def getCurrentWindow(self) -> AnyStr: ...
    def goBack(self) -> PyObject: ...
    def goForward(self) -> PyObject: ...
    def goHome(self) -> PyObject: ...
    def openWindow(
        self, path: AnyStr, params: Optional[Dict[AnyStr, Any]] = ...
    ) -> PyObject: ...
    def openWindowImpl(
        self, path: AnyStr, params: Dict[AnyStr, Any], openAdditional: bool
    ) -> PyObject: ...
    def openWindowInstance(
        self, path: AnyStr, params: Optional[Dict[AnyStr, Any]] = ...
    ) -> PyObject: ...
    def swapTo(self, name: AnyStr, params: Dict[AnyStr, Any]) -> PyObject: ...
    def swapWindow(self, *args: Any) -> PyObject: ...

class ClientDatasetUtilities(Object):
    def __init__(self, app: FPMIApp) -> None: ...

class ClientSystemUtilities(Object):
    def __init__(self) -> None: ...

class NavUtilities(INavUtilities):
    def centerWindow(self, arg: Union[FPMIWindow, AnyStr]) -> None: ...
    def closeParentWindow(self, event: EventObject) -> None: ...
    def closeWindow(self, arg: Union[FPMIWindow, AnyStr]) -> None: ...
    def getCurrentWindow(self) -> AnyStr: ...
    def goBack(self) -> PyObject: ...
    def goForward(self) -> PyObject: ...
    def goHome(self) -> PyObject: ...
    def openWindow(
        self, path: AnyStr, params: Optional[Dict[AnyStr, Any]] = ...
    ) -> PyObject: ...
    def openWindowImpl(
        self, path: AnyStr, params: Dict[AnyStr, Any], openAdditional: bool
    ) -> PyObject: ...
    def openWindowInstance(
        self, path: AnyStr, params: Optional[Dict[AnyStr, Any]] = ...
    ) -> PyObject: ...
    def swapTo(self, name: AnyStr, params: Dict[AnyStr, Any]) -> PyObject: ...
    def swapWindow(self, *args: Any) -> PyObject: ...

class PrintUtilities(Object):
    def __init__(self, app: Any) -> None: ...
    def createImage(self, c: Component) -> BufferedImage: ...
    def createPrintJob(self, c: Component) -> PrintUtilities.JythonPrintJob: ...
    def printToImage(self, c: Component, fileName: Optional[str] = ...) -> None: ...

    class ComponentPrinter(Object):
        def __init__(self, c: Component, fit: bool, zoom: float) -> None: ...
        def print(self, g: Graphics, pageFormat: PageFormat, pageIndex: int) -> int: ...

    class JythonPrintJob(Object):
        def __init__(self, c: Component) -> None: ...
        def getBottomMargin(self) -> float: ...
        def getLeftMargin(self) -> float: ...
        def getOrientation(self) -> int: ...
        def getPageHeight(self) -> float: ...
        def getPageWidth(self) -> float: ...
        def getPrinterName(self) -> AnyStr: ...
        def getRightMargin(self) -> float: ...
        def getTopMargin(self) -> float: ...
        def getZoomFactor(self) -> float: ...
        def isFitToPage(self) -> bool: ...
        def isShowPrintDialog(self) -> bool: ...
        def setBottomMargin(self, bottomMargin: float) -> None: ...
        def setFitToPage(self, fitToPage: bool) -> None: ...
        def setLeftMargin(self, leftMargin: float) -> None: ...
        def setMargins(self, m: float) -> None: ...
        def setOrientation(self, orientation: int) -> None: ...
        def setPageHeight(self, pageHeight: float) -> None: ...
        def setPageWidth(self, pageWidth: float) -> None: ...
        def setPrinterName(self, printerName: AnyStr) -> None: ...
        def setRightMargin(self, rightMargin: float) -> None: ...
        def setShowPrintDialog(self, showPrintDialog: bool) -> None: ...
        def setZoomFactor(self, zoomFactor: float) -> None: ...

class WindowUtilities(Object):
    ACCL_NONE: int
    ACCL_CONSTANT: int
    ACCL_FAST_TO_SLOW: int
    ACCL_SLOW_TO_FAST: int
    ACCL_EASE: int
    COORD_DESIGNER: int
    COORD_SCREEN: int
    def chooseColor(
        self, initialColor: Color, dialogTitle: Optional[AnyStr] = ...
    ) -> Color: ...
    def closeDesktop(self, handle: AnyStr) -> None: ...
    @staticmethod
    def color(*args: Any) -> Color: ...
    def confirm(
        self, message: AnyStr, title: AnyStr = ..., allowCancel: bool = ...
    ) -> Optional[bool]: ...
    @staticmethod
    def convertPointToScreen(x: int, y: int, event: EventObject) -> Tuple[int, int]: ...
    @staticmethod
    def createPopupContext() -> WindowUtilities.PopupContext: ...
    @staticmethod
    def createPopupMenu(key: PySequence, functions: PySequence) -> JPopupMenu: ...
    def desktop(self, arg: Union[int, AnyStr]) -> WindowUtilities: ...
    def errorBox(self, message: AnyStr, title: Optional[AnyStr] = ...) -> None: ...
    @staticmethod
    def find(component: JComponent) -> WindowUtilities: ...
    def findWindow(self, path: AnyStr) -> List[PyComponentWrapper]: ...
    def getCurrentDesktop(self) -> AnyStr: ...
    def getDesktopHandles(self) -> PySequence: ...
    def getOpenedWindowNames(self) -> PyTuple: ...
    def getOpenedWindows(self) -> PyTuple: ...
    @staticmethod
    def getParentWindow(event: EventObject) -> PyObject: ...
    def getQuality(self, comp: JComponent, propertyName: AnyStr) -> QualityCode: ...
    def getScreenIndex(self) -> int: ...
    @staticmethod
    def getScreens() -> PySequence: ...
    @staticmethod
    def getSibling(event: EventObject, name: AnyStr) -> PyObject: ...
    def getWindow(self, name: AnyStr) -> PyObject: ...
    def getWindowNames(self) -> PyTuple: ...
    def inputBox(
        self, message: AnyStr, defaultTxt: AnyStr = ...
    ) -> Optional[AnyStr]: ...
    def isTouchscreenModeEnabled(self) -> bool: ...
    def messageBox(self, message: AnyStr, title: AnyStr = ...) -> None: ...
    def openDesktop(self, *args: PyObject, **kwargs: AnyStr) -> JFrame: ...
    def openDiagnostics(self) -> None: ...
    def passwordBox(
        self, message: AnyStr, title: AnyStr = ..., echoChar: AnyStr = ...
    ) -> Optional[AnyStr]: ...
    def setTouchScreenModeEnabled(self, b: bool) -> None: ...
    def showNumericKeyPad(
        self,
        initialValue: Number,
        fontSize: Optional[int] = ...,
        usePasswordMode: bool = ...,
    ) -> Number: ...
    def showTouchscreenKeyboard(
        self,
        initialText: AnyStr,
        fontSize: Optional[int] = ...,
        password: Optional[bool] = ...,
    ) -> AnyStr: ...
    def transform(self, *args: PyObject, **kwargs: AnyStr) -> PyObject: ...
    def warningBox(self, message: AnyStr, title: AnyStr = ...) -> None: ...

    class JyPopupMenu(JPopupMenu):
        def actionPerformed(self, e: ActionEvent) -> None: ...
        def addJyFunction(self, name: AnyStr, fun: PyObject) -> None: ...
        def show(self, me: Union[ComponentEvent, MouseEvent], *args: int) -> None: ...

    class PopupContext(Object):
        def endPopup(self) -> None: ...
        def startPopup(self) -> None: ...



from typing import Any, Iterator, List, Optional

from com.inductiveautomation.ignition.common.model.values import (
    QualifiedValue,
    QualityCode,
)
from com.inductiveautomation.ignition.common.sqltags.model.types import (
    DataType,
    DataTypeClass,
)
from dev.coatl.helper.types import AnyStr
from java.lang import Object

class AttributeInfo(Object):
    def __init__(self, *args: Any) -> None: ...
    def getDesc(self) -> AnyStr: ...
    def getId(self) -> int: ...
    def getName(self) -> AnyStr: ...
    def getType(self) -> DataType: ...
    def setType(self, type_: DataType) -> None: ...

class ReadResult(Object):
    def __init__(self, serviceResult: Optional[QualityCode] = ...) -> None: ...
    def getServiceResult(self) -> QualityCode: ...
    def getTypeClass(self) -> DataTypeClass: ...
    def getValues(self) -> List[QualifiedValue]: ...
    def iterator(self) -> Iterator[QualifiedValue]: ...
    def setServiceResult(self, serviceResult: QualityCode) -> None: ...
    def setTypeClass(self, typeClass: DataTypeClass) -> None: ...
    def setValues(self, values: List[QualifiedValue]) -> None: ...
    def size(self) -> int: ...



from typing import Optional

from com.inductiveautomation.vision.api.client.components.model import (
    AbstractVisionPanel,
)
from dev.coatl.helper.types import AnyStr

class BasicContainer(AbstractVisionPanel):
    def __init__(self, name: Optional[AnyStr] = ...) -> None: ...



from typing import List, Optional, Union

from com.inductiveautomation.ignition.common.messages import UIResponse
from com.inductiveautomation.ignition.common.user import PyUser, UserSourceMeta
from com.inductiveautomation.ignition.common.user.schedule import (
    AbstractScheduleModel,
    HolidayModel,
    ScheduleAdjustment,
)
from dev.coatl.helper.types import AnyStr
from java.util import Date

def addCompositeSchedule(
    name: AnyStr,
    scheduleOne: AnyStr,
    scheduleTwo: AnyStr,
    description: Optional[AnyStr] = ...,
) -> UIResponse: ...
def addHoliday(holiday: HolidayModel) -> UIResponse: ...
def addRole(userSource: AnyStr, role: AnyStr) -> UIResponse: ...
def addSchedule(schedule: AbstractScheduleModel) -> UIResponse: ...
def addUser(userSource: AnyStr, user: PyUser) -> UIResponse: ...
def createScheduleAdjustment(
    startDate: Date, endDate: Date, isAvailable: bool, note: AnyStr
) -> ScheduleAdjustment: ...
def editHoliday(holidayName: AnyStr, holiday: HolidayModel) -> UIResponse: ...
def editRole(userSource: AnyStr, oldName: AnyStr, newName: AnyStr) -> UIResponse: ...
def editSchedule(
    scheduleName: AnyStr, schedule: AbstractScheduleModel
) -> UIResponse: ...
def editUser(userSource: AnyStr, user: PyUser) -> UIResponse: ...
def getHoliday(holidayName: AnyStr) -> Optional[HolidayModel]: ...
def getHolidayNames() -> List[AnyStr]: ...
def getHolidays() -> List[HolidayModel]: ...
def getNewUser(userSource: AnyStr, username: AnyStr) -> PyUser: ...
def getRoles(userSource: AnyStr) -> List[AnyStr]: ...
def getSchedule(scheduleName: AnyStr) -> Optional[AbstractScheduleModel]: ...
def getScheduleNames() -> List[AnyStr]: ...
def getScheduledUsers(
    userSource: AnyStr, date: Optional[Union[Date, int]] = ...
) -> List[PyUser]: ...
def getSchedules() -> List[AbstractScheduleModel]: ...
def getUser(userSource: AnyStr, username: AnyStr) -> PyUser: ...
def getUserSources() -> List[UserSourceMeta]: ...
def getUsers(userSource: AnyStr) -> List[PyUser]: ...
def isUserScheduled(user: PyUser, date: Optional[Union[Date, int]] = ...) -> bool: ...
def removeHoliday(holidayName: AnyStr) -> UIResponse: ...
def removeRole(userSource: AnyStr, role: AnyStr) -> UIResponse: ...
def removeSchedule(scheduleName: AnyStr) -> UIResponse: ...
def removeUser(userSource: AnyStr, username: AnyStr) -> UIResponse: ...



from typing import Iterable, List, Optional

from com.inductiveautomation.ignition.common.i18n import LocalizedString
from com.inductiveautomation.ignition.common.model.values import Quality, QualityCode
from dev.coatl.helper.types import AnyStr
from java.lang import Class, Enum, Object
from java.util import Locale

class DataQuality(Object):
    @staticmethod
    def fromIntValue(value: int) -> DataQuality: ...
    def getDescription(self) -> LocalizedString: ...
    def getIntValue(self) -> int: ...
    def getLevel(self) -> Quality.Level: ...
    def getName(self) -> str: ...
    def getQualityCode(self) -> QualityCode: ...
    @staticmethod
    def getQualityFor(value: int) -> DataQuality: ...
    def isDataUsed(self) -> bool: ...
    def isGood(self) -> bool: ...
    def isGoodData(self) -> bool: ...
    def isOpcBadData(self) -> bool: ...
    def toString(self, locale: Optional[Locale] = ...) -> AnyStr: ...
    @staticmethod
    def valueOf(name: str) -> DataQuality: ...
    @staticmethod
    def values() -> List[DataQuality]: ...
    @staticmethod
    def worstOf(q1: DataQuality, q2: DataQuality) -> DataQuality: ...
    @staticmethod
    def worstOfAll(*args: DataQuality) -> DataQuality: ...

class DataType(Enum):
    @staticmethod
    def fromIntValue(val: int) -> DataType: ...
    def getComponentDataType(self) -> DataType: ...
    def getIntValue(self) -> int: ...
    def getJavaType(self) -> Class: ...
    def getTypeClass(self) -> DataTypeClass: ...
    @staticmethod
    def getTypeForClass(clazz: Class) -> DataType: ...
    @staticmethod
    def getTypeForValue(val: int) -> DataType: ...
    def isArray(self) -> bool: ...
    def isFloatingPoint(self) -> bool: ...
    def isNumeric(self) -> bool: ...
    def legacyDataType(self) -> DataType: ...
    @staticmethod
    def values() -> Iterable[DataType]: ...

class DataTypeClass(Enum):
    @staticmethod
    def values() -> Iterable[DataTypeClass]: ...



from typing import Any, Dict, List, Optional, Set, Union

from dev.coatl.helper.types import AnyStr
from java.lang import Number, Object, StringBuffer
from java.math import RoundingMode
from java.util import Calendar, Currency, Date, Locale, TimeZone

class CharacterIterator:
    DONE: str
    def clone(self) -> str: ...
    def current(self) -> str: ...
    def first(self) -> str: ...
    def getBeginIndex(self) -> int: ...
    def getEndIndex(self) -> int: ...
    def getIndex(self) -> int: ...
    def last(self) -> str: ...
    def next(self) -> str: ...
    def previous(self) -> str: ...
    def setIndex(self, position: int) -> str: ...

class AttributedCharacterIterator(CharacterIterator):
    def clone(self) -> str: ...
    def current(self) -> str: ...
    def first(self) -> str: ...
    def getAllAttributeKeys(self) -> Set[AttributedCharacterIterator.Attribute]: ...
    def getAttribute(
        self, attribute: AttributedCharacterIterator.Attribute
    ) -> Object: ...
    def getAttributes(self) -> Dict[AttributedCharacterIterator.Attribute, Object]: ...
    def getBeginIndex(self) -> int: ...
    def getEndIndex(self) -> int: ...
    def getIndex(self) -> int: ...
    def last(self) -> str: ...
    def next(self) -> str: ...
    def previous(self) -> str: ...
    def setIndex(self, position: int) -> str: ...

    class Attribute(Object):
        INPUT_METHOD_SEGMENT: AttributedCharacterIterator.Attribute
        LANGUAGE: AttributedCharacterIterator.Attribute
        READING: AttributedCharacterIterator.Attribute

class FieldPosition(Object):
    def __init__(self, *args: Any) -> None: ...
    def getBeginIndex(self) -> int: ...
    def getEndIndex(self) -> int: ...
    def getField(self) -> Any: ...
    def getFieldAttribute(self) -> Format.Field: ...
    def setBeginIndex(self, bi: int) -> None: ...
    def setEndIndex(self, ei: int) -> None: ...

class Format(Object):
    def clone(self) -> Object: ...
    def formatToCharacterIterator(self, obj: Object) -> AttributedCharacterIterator: ...
    def parseObject(
        self, source: AnyStr, pos: Optional[ParsePosition] = ...
    ) -> Object: ...

    class Field(AttributedCharacterIterator.Attribute): ...

class DateFormat(Format):
    AM_PM_FIELD: int
    DATE_FIELD: int
    DAY_OF_WEEK_FIELD: int
    DAY_OF_WEEK_IN_MONTH_FIELD: int
    DAY_OF_YEAR_FIELD: int
    DEFAULT: int
    ERA_FIELD: int
    FULL: int
    HOUR_OF_DAY0_FIELD: int
    HOUR_OF_DAY1_FIELD: int
    HOUR0_FIELD: int
    HOUR1_FIELD: int
    LONG: int
    MEDIUM: int
    MILLISECOND_FIELD: int
    MONTH_FIELD: int
    SECOND_FIELD: int
    SHORT: int
    TIMEZONE_FIELD: int
    WEEK_OF_MONTH_FIELD: int
    WEEK_OF_YEAR_FIELD: int
    YEAR_FIELD: int
    def format(
        self,
        date: Union[Date, Object],
        toAppendTo: Optional[StringBuffer] = ...,
        pos: Optional[FieldPosition] = ...,
    ) -> Union[AnyStr, StringBuffer]: ...
    @staticmethod
    def getAvailableLocales() -> List[Locale]: ...
    def getCalendar(self) -> Calendar: ...
    @staticmethod
    def getDateInstance(
        style: Optional[int] = ..., aLocale: Optional[Locale] = ...
    ) -> DateFormat: ...
    @staticmethod
    def getDateTimeInstance() -> DateFormat: ...
    @staticmethod
    def getInstance() -> DateFormat: ...
    def getNumberFormat(self) -> NumberFormat: ...
    @staticmethod
    def getTimeInstance(style: int, aLocale: Optional[Locale] = ...) -> DateFormat: ...
    def getTimeZone(self) -> TimeZone: ...
    def isLenient(self) -> bool: ...
    def parse(self, source: AnyStr) -> Date: ...
    def setCalendar(self, newCalendar: Calendar) -> None: ...
    def setLenient(self, lenient: bool) -> None: ...
    def setNumberFormat(self, newNumberFormat: NumberFormat) -> None: ...
    def setTimeZone(self, zone: TimeZone) -> None: ...

class DateFormatSymbols(Object):
    def __init__(self, locale: Optional[Locale] = ...) -> None: ...
    def clone(self) -> Object: ...
    def getAmPmStrings(self) -> List[AnyStr]: ...
    @staticmethod
    def getAvailableLocales() -> List[Locale]: ...
    def getEras(self) -> List[AnyStr]: ...
    @staticmethod
    def getInstance(locale: Optional[Locale] = ...) -> DateFormatSymbols: ...
    def getLocalPatternChars(self) -> AnyStr: ...
    def getMonths(self) -> List[AnyStr]: ...
    def getShortMonths(self) -> List[AnyStr]: ...
    def getShortWeekdays(self) -> List[AnyStr]: ...
    def getWeekdays(self) -> List[AnyStr]: ...
    def getZoneStrings(self) -> List[List[AnyStr]]: ...
    def setAmPmStrings(self, newAmpms: List[AnyStr]) -> None: ...
    def setEras(self, newEras: List[AnyStr]) -> None: ...
    def setLocalPatternChars(self, newLocalPatternChars: AnyStr) -> None: ...
    def setMonths(self, newMonths: List[AnyStr]) -> None: ...
    def setShortMonths(self, newShortMonths: List[AnyStr]) -> None: ...
    def setShortWeekdays(self, newShortWeekdays: List[AnyStr]) -> None: ...
    def setWeekdays(self, newWeekdays: List[AnyStr]) -> None: ...
    def setZoneStrings(self, newZoneStrings: List[List[AnyStr]]) -> None: ...

class NumberFormat(Format):
    FRACTION_FIELD: int
    INTEGER_FIELD: int
    def format(
        self,
        number: Union[float, long, Object],
        toAppendTo: Optional[StringBuffer] = ...,
        pos: Optional[FieldPosition] = ...,
    ) -> Union[AnyStr, StringBuffer]: ...
    @staticmethod
    def getAvailableLocales() -> List[Locale]: ...
    def getCurrency(self) -> Currency: ...
    @staticmethod
    def getCurrencyInstance(inLocale: Optional[Locale] = ...) -> NumberFormat: ...
    @staticmethod
    def getInstance(inLocale: Optional[Locale] = ...) -> NumberFormat: ...
    @staticmethod
    def getIntegerInstance(inLocale: Optional[Locale] = ...) -> NumberFormat: ...
    def getMaximumFractionDigits(self) -> int: ...
    def getMaximumIntegerDigits(self) -> int: ...
    def getMinimumFractionDigits(self) -> int: ...
    def getMinimumIntegerDigits(self) -> int: ...
    @staticmethod
    def getNumberInstance(inLocale: Optional[Locale] = ...) -> NumberFormat: ...
    @staticmethod
    def getPercentInstance(inLocale: Optional[Locale] = ...) -> NumberFormat: ...
    def getRoundingMode(self) -> RoundingMode: ...
    def isGroupingUsed(self) -> bool: ...
    def isParseIntegerOnly(self) -> bool: ...
    def parse(self, source: AnyStr) -> Number: ...
    def setCurrency(self, currency: Currency) -> None: ...
    def setGroupingUsed(self, newValue: bool) -> None: ...
    def setMaximumFractionDigits(self, newValue: int) -> None: ...
    def setMaximumIntegerDigits(self, newValue: int) -> None: ...
    def setMinimumFractionDigits(self, newValue: int) -> None: ...
    def setMinimumIntegerDigits(self, newValue: int) -> None: ...
    def setParseIntegerOnly(self, value: bool) -> None: ...
    def setRoundingMode(self, roundingMode: RoundingMode) -> None: ...

    class Field(Format.Field):
        CURRENCY: NumberFormat.Field
        DECIMAL_SEPARATOR: NumberFormat.Field
        EXPONENT: NumberFormat.Field
        EXPONENT_SIGN: NumberFormat.Field
        EXPONENT_SYMBOL: NumberFormat.Field
        FRACTION: NumberFormat.Field
        GROUPING_SEPARATOR: NumberFormat.Field
        INTEGER: NumberFormat.Field
        PERCENT: NumberFormat.Field
        PERMILLE: NumberFormat.Field
        SIGN: NumberFormat.Field

class ParsePosition(Object):
    def __init__(self, index: int) -> None: ...
    def getErrorIndex(self) -> int: ...
    def getIndex(self) -> int: ...
    def setErrorIndex(self, ei: int) -> None: ...
    def setIndex(self, index: int) -> None: ...

class SimpleDateFormat(DateFormat):
    def __init__(
        self,
        pattern: Optional[AnyStr] = ...,
        arg: Union[DateFormatSymbols, Locale, None] = ...,
    ) -> None: ...
    def applyLocalizedPattern(self, pattern: AnyStr) -> None: ...
    def applyPattern(self, pattern: AnyStr) -> None: ...
    def get2DigitYearStart(self) -> Date: ...
    def getDateFormatSymbols(self) -> DateFormatSymbols: ...
    def set2DigitYearStart(self, startDate: Date) -> None: ...
    def setDateFormatSymbols(self, newFormatSymbols: DateFormatSymbols) -> None: ...
    def toLocalizedPattern(self) -> AnyStr: ...
    def toPattern(self) -> AnyStr: ...



from typing import Dict, List, Union

from com.inductiveautomation.ignition.alarming.common.rosters import RosterModel
from com.inductiveautomation.ignition.common.user import PyUser
from dev.coatl.helper.types import AnyStr

def addUsers(rosterName: AnyStr, users: List[PyUser]) -> None: ...
def createRoster(name: AnyStr, description: Union[AnyStr, None]) -> None: ...
def deleteRoster(rosterName: AnyStr) -> None: ...
def getRoster(name: AnyStr) -> RosterModel: ...
def getRosterNames() -> List[AnyStr]: ...
def getRosters() -> Dict[AnyStr, List[AnyStr]]: ...
def removeUsers(rosterName: AnyStr, users: List[PyUser]) -> None: ...



from typing import Any, List, Optional

from com.inductiveautomation.ignition.common import BasicDataset
from com.inductiveautomation.ignition.common.script.builtin import (
    DatasetUtilities,
    SProcCall,
)
from dev.coatl.helper.types import AnyStr
from java.util import Date
from javax.swing import JComponent

BIT: int
REAL: int
LONGVARCHAR: int
LONGVARBINARY: int
TINYINT: int
DOUBLE: int
DATE: int
NULL: int
SMALLINT: int
NUMERIC: int
TIME: int
ROWID: int
INTEGER: int
DECIMAL: int
TIMESTAMP: int
CLOB: int
BIGINT: int
CHAR: int
BINARY: int
NCLOB: int
FLOAT: int
VARCHAR: int
VARBINARY: int
BLOB: int
NCHAR: int
NVARCHAR: int
LONGNVARCHAR: int
BOOLEAN: int
ORACLE_CURSOR: int
DISTINCT: int
STRUCT: int
REF: int
JAVA_OBJECT: int
SQLXML: int
ARRAY: int
DATALINK: int
OTHER: int
READ_COMMITTED: int
READ_UNCOMMITTED: int
REPEATABLE_READ: int
SERIALIZABLE: int

def addDatasource(
    jdbcDriver: AnyStr,
    name: AnyStr,
    description: AnyStr = ...,
    connectUrl: Optional[AnyStr] = ...,
    username: Optional[AnyStr] = ...,
    password: Optional[AnyStr] = ...,
    props: Optional[AnyStr] = ...,
    validationQuery: Optional[AnyStr] = ...,
    maxConnections: int = ...,
) -> None: ...
def beginNamedQueryTransaction(*args: Any, **kwargs: Any) -> AnyStr: ...
def beginTransaction(
    database: Optional[AnyStr] = ...,
    isolationLevel: Optional[int] = ...,
    timeout: Optional[int] = ...,
) -> AnyStr: ...
def clearAllNamedQueryCaches(project: Optional[AnyStr] = ...) -> None: ...
def clearNamedQueryCache(*args: AnyStr, **kwargs: AnyStr) -> None: ...
def closeTransaction(tx: AnyStr) -> None: ...
def commitTransaction(tx: AnyStr) -> None: ...
def createSProcCall(
    procedureName: AnyStr,
    database: AnyStr = ...,
    tx: Optional[AnyStr] = ...,
    skipAudit: bool = ...,
) -> SProcCall: ...
def dateFormat(date: Date, formatPattern: AnyStr) -> AnyStr: ...
def execSProcCall(callContext: SProcCall) -> None: ...
def getConnectionInfo(name: Optional[AnyStr] = ...) -> BasicDataset: ...
def getConnections() -> BasicDataset: ...
def refresh(component: JComponent, propertyName: AnyStr) -> bool: ...
def removeDatasource(name: AnyStr) -> None: ...
def rollbackTransaction(tx: AnyStr) -> None: ...
def runNamedQuery(*args: Any, **kwargs: Any) -> Any: ...
def runPrepQuery(
    query: AnyStr, args: List[Any], database: AnyStr = ..., tx: Optional[AnyStr] = ...
) -> DatasetUtilities.PyDataSet: ...
def runPrepUpdate(
    query: AnyStr,
    args: List[Any],
    database: AnyStr = ...,
    tx: Optional[AnyStr] = ...,
    getKey: bool = ...,
    skipAudit: bool = ...,
) -> int: ...
def runQuery(
    query: AnyStr, database: AnyStr = ..., tx: Optional[AnyStr] = ...
) -> DatasetUtilities.PyDataSet: ...
def runSFNamedQuery(*args: Any, **kwargs: Any) -> bool: ...
def runSFPrepUpdate(
    query: AnyStr, args: List[Any], datasources: List[AnyStr]
) -> bool: ...
def runSFUpdateQuery(query: AnyStr, datasources: List[AnyStr]) -> bool: ...
def runScalarPrepQuery(
    query: AnyStr, args: List[Any], database: AnyStr = ..., tx: Optional[AnyStr] = ...
) -> Any: ...
def runScalarQuery(
    query: AnyStr, database: Optional[AnyStr] = ..., tx: Optional[AnyStr] = ...
) -> Any: ...
def runUpdateQuery(
    query: AnyStr,
    database: AnyStr = ...,
    tx: Optional[AnyStr] = ...,
    getKey: bool = ...,
    skipAudit: bool = ...,
) -> int: ...
def setDatasourceConnectURL(name: AnyStr, connectUrl: AnyStr) -> None: ...
def setDatasourceEnabled(name: AnyStr, enabled: bool) -> None: ...
def setDatasourceMaxConnections(name: AnyStr, maxConnections: int) -> None: ...



from typing import Any, List, Optional

from com.inductiveautomation.ignition.modules.serial.scripting import SerialScriptModule
from dev.coatl.helper.types import AnyStr

BIT_RATE_110: int
BIT_RATE_150: int
BIT_RATE_300: int
BIT_RATE_600: int
BIT_RATE_1200: int
BIT_RATE_2400: int
BIT_RATE_4800: int
BIT_RATE_9600: int
BIT_RATE_19200: int
BIT_RATE_38400: int
BIT_RATE_57600: int
BIT_RATE_115200: int
BIT_RATE_230400: int
BIT_RATE_460800: int
BIT_RATE_921600: int
DATA_BITS_5: int
DATA_BITS_6: int
DATA_BITS_7: int
DATA_BITS_8: int
HANDSHAKE_CTS_DTR: int
HANDSHAKE_CTS_RTS: int
HANDSHAKE_DSR_DTR: int
HANDSHAKE_HARD_IN: int
HANDSHAKE_HARD_OUT: int
HANDSHAKE_NONE: int
HANDSHAKE_SOFT_IN: int
HANDSHAKE_SOFT_OUT: int
HANDSHAKE_SPLIT_MASK: int
HANDSHAKE_XON_XOFF: int
PARITY_EVEN: int
PARITY_ODD: int
PARITY_MARK: int
PARITY_SPACE: int
PARITY_NONE: int
STOP_BITS_1: int
STOP_BITS_2: int

def closeSerialPort(port: AnyStr) -> None: ...
def configureSerialPort(
    port: AnyStr,
    bitRate: Optional[int] = ...,
    dataBits: Optional[int] = ...,
    handshake: Optional[int] = ...,
    hardwareFlowControl: Optional[bool] = ...,
    parity: Optional[int] = ...,
    stopBits: Optional[int] = ...,
) -> SerialScriptModule.SerialConfigurator: ...
def openSerialPort(port: AnyStr) -> None: ...
def port(
    port: AnyStr,
    bitRate: Optional[int] = ...,
    dataBits: Optional[int] = ...,
    handshake: Optional[int] = ...,
    hardwareFlowControl: Optional[bool] = ...,
    parity: Optional[int] = ...,
    stopBits: Optional[int] = ...,
) -> SerialScriptModule.PortManager: ...
def readBytes(
    port: AnyStr, numberOfBytes: int, timeout: Optional[int] = ...
) -> List[Any]: ...
def readBytesAsString(
    port: AnyStr, numberOfBytes: int, timeout: int = ..., encoding: AnyStr = ...
) -> AnyStr: ...
def readLine(
    port: AnyStr, timeout: int = ..., encoding: AnyStr = ..., crlfRequired: bool = ...
) -> AnyStr: ...
def readUntil(
    port: AnyStr,
    delimiter: AnyStr,
    includeDelimiter: bool,
    timeout: Optional[int] = ...,
) -> AnyStr: ...
def sendBreak(port: AnyStr, millis: int) -> None: ...
def write(
    port: AnyStr, toWrite: AnyStr, timeout: int = ..., encoding: Optional[AnyStr] = ...
) -> None: ...
def writeBytes(port: AnyStr, toWrite: Any, timeout: Optional[int] = ...) -> None: ...



from typing import Any, List, Optional, Union

from com.inductiveautomation.ignition.common.config import Property
from com.inductiveautomation.ignition.common.tags.model import TagPath
from dev.coatl.helper.types import AnyStr
from java.lang import Object

class AbstractTagPath(Object, TagPath):
    def __init__(self) -> None: ...
    @staticmethod
    def compareNullLow(c1: Property, c2: Property) -> int: ...
    def getChildPath(self, nextId: AnyStr) -> TagPath: ...
    def getItemName(self) -> AnyStr: ...
    def getParentPath(self) -> TagPath: ...
    def getProperty(self) -> Property: ...
    def getSource(self) -> AnyStr: ...
    def toStringFull(self) -> AnyStr: ...
    def toStringPartial(self) -> AnyStr: ...

class BasicTagPath(AbstractTagPath):
    def __init__(
        self,
        source: AnyStr,
        pathParts: Optional[List[AnyStr]] = ...,
        prop: Optional[Property] = ...,
    ) -> None: ...
    @staticmethod
    def append(root: TagPath, arg: Union[AnyStr, TagPath]) -> TagPath: ...
    @staticmethod
    def copy(path: TagPath) -> BasicTagPath: ...
    @staticmethod
    def renameParentFolder(path: TagPath, newParent: TagPath) -> BasicTagPath: ...
    @staticmethod
    def subPath(path: TagPath, *args: Any) -> BasicTagPath: ...

class PropertyAlteredTagPath(AbstractTagPath):
    def __init__(self, path: TagPath, prop: Property) -> None: ...

class SourceAlteredTagPath(AbstractTagPath):
    def __init__(self, path: TagPath, source: AnyStr) -> None: ...



from typing import Any, Dict, List, Tuple

from dev.coatl.helper.types import AnyStr

def addConnection(
    name: AnyStr,
    description: AnyStr,
    discoveryUrl: AnyStr,
    endpointUrl: AnyStr,
    securityPolicy: AnyStr,
    securityMode: AnyStr,
    settings: Dict[AnyStr, Any],
) -> None: ...
def callMethod(
    connectionName: AnyStr, objectId: AnyStr, methodId: AnyStr, inputs: List[Any]
) -> Tuple[Any, Any, Any]: ...
def removeConnection(name: AnyStr) -> bool: ...



from typing import Optional

from java.awt import LayoutManager
from javax.swing import JPanel

class AbstractVisionPanel(JPanel):
    def __init__(
        self,
        layout: Optional[LayoutManager] = ...,
        isDoubleBuffered: Optional[bool] = ...,
    ) -> None: ...



from typing import Any, Optional, Set

from dev.coatl.helper.types import AnyStr
from java.lang import Object, Throwable
from java.util import Locale

class ExceptionContext(Object):
    def __init__(self, throwable: Throwable) -> None: ...
    def addMessage(self, pattern: AnyStr, *args: Any) -> None: ...
    def getKeys(self) -> Set[AnyStr]: ...
    def getLocalizedMessage(self) -> AnyStr: ...
    def getMessage(
        self, locale: Optional[Locale] = ..., separator: Optional[AnyStr] = ...
    ) -> AnyStr: ...
    def getThrowable(self) -> Throwable: ...
    def getValue(self, key: AnyStr) -> None: ...
    def setValue(self, key: AnyStr, value: Object) -> None: ...



from typing import Any, Iterable, Set

from com.inductiveautomation.ignition.common.binding import InteractionListener
from com.inductiveautomation.ignition.common.expressions.functions import Function
from com.inductiveautomation.ignition.common.model.values import QualifiedValue
from dev.coatl.helper.types import AnyStr
from java.lang import Class

class Expression:
    def connect(self, context: Any, updateListener: InteractionListener) -> None: ...
    def disconnect(self) -> None: ...
    def execute(self, args: Iterable[Expression]) -> QualifiedValue: ...
    def getChildren(self) -> Iterable[Expression]: ...
    def getOpName(self) -> AnyStr: ...
    def getType(self) -> Class: ...
    def shutdown(self) -> None: ...
    def startup(self) -> None: ...

class FunctionFactory:
    def getCategories(self) -> Set[AnyStr]: ...
    def getFunction(self, name: AnyStr) -> Function: ...
    def getFunctionNames(self) -> Set[AnyStr]: ...
    def getFunctionsInCategory(self, name: AnyStr) -> Set[AnyStr]: ...



from typing import Any, Dict, Optional

from com.inductiveautomation.ignition.common import BasicDataset
from com.inductiveautomation.sfc.api import PyChartScope
from dev.coatl.helper.types import AnyStr

def cancelChart(instanceId: AnyStr) -> None: ...
def getRunningCharts(chartPath: Optional[AnyStr] = ...) -> BasicDataset: ...
def getVariables(instanceId: AnyStr) -> PyChartScope: ...
def pauseChart(instanceId: AnyStr) -> None: ...
def redundantCheckpoint(instanceId: AnyStr) -> None: ...
def resumeChart(instanceId: AnyStr) -> None: ...
def setVariable(
    instanceId: AnyStr, stepId: AnyStr, variableName: AnyStr, variableValue: Any
) -> None: ...
def setVariables(
    instanceId: AnyStr, stepId: AnyStr, variableMap: Dict[AnyStr, Any]
) -> None: ...
def startChart(
    projectName: AnyStr, chartPath: AnyStr, arguments: Dict[AnyStr, Any]
) -> AnyStr: ...
